@@ -722,7 +722,7 @@ sub _validate_skipfile {
     my ($self, $name, $option) = @_;
     return unless $option;
     my $skipfile = File::Spec->file_name_is_absolute( $option )
-                 ? $option : File::Spec->catfile( _get_config_dir(), $option );
+                 ? $option : File::Spec->catfile( get_config_dir(), $option );
     return -r $skipfile ? $skipfile : undef;
 }
 
@@ -814,7 +814,7 @@ a proper C<prompt> function when you instantiated the object.
 =head2 get_config_dir()
 
 The base directory in which your 'C<config.ini>' and other files reside.
-Defaults to the '.cpantesters' directory  under your home directory
+Defaults to the '.cpanreporter' directory  under your home directory
 (if you're using Linux or OS X) or under the 'my documents' folder
 (if you're running Windows).
 
